/************************************************************
 *  GAI - Temp                                              *
 *                                                          *
 *  A temperature displaying applet using GAI               *
 *                                                          *
 ************************************************************/

/************************************************************
 *  Released unter GPL                                      *
 ************************************************************/

#ifndef GAI_TEMP_H
#define GAI_TEMP_H

#include <string.h>
#include <stdio.h>

#include <gai/gai.h>
#include <glib.h>

#include <stdlib.h>

#include "config.h"

#include "readtemp.h"



#define _(a) a /* a dummy for multi language support */



/* some macros to code and decode a color byte in a 32-bit int */

#define GET_COL_R(col) (col&(255<<24))>>24
#define GET_COL_G(col) (col&(255<<16))>>16
#define GET_COL_B(col) (col&(255<<8))>>8
#define GET_COL_A(col) (col&255)

#define COL_R(col) ((col&255)<<24)
#define COL_G(col) ((col&255)<<16)
#define COL_B(col) ((col&255)<<8)
#define COL_A(col) (col&255)

#define COL_STRUCT_INT32(cst) COL_R(cst.r)+COL_G(cst.g)+COL_B(cst.b)+COL_A(cst.alpha)

#undef MAX
#define MAX(a,b) ((a>b)?a:b)

/************************************************************


   _______________________________
  |b  b   b   b   b   b   b   b  b|
  |   *****   |                   |
  |b * IMG *  s   Temp           b|
  |  *     *  |                   |
  |b *     *  s                  b|
  |   *****   |                   |
  |b__b___b___b___b___b___b___b__b|
  

  b == size of an invisible border around the whole object (px)
  s == spacing between the image and the text


 ************************************************************/


/*
  What sources do we have?
  - ACPI CPU temp.
  - hddtemp daemon

*/

enum 
{
    ACPI_CPU = 0,
    HDDTEMP,
    LM_SENSORS,
    TEMP_SOURCES
} TEMP_SOURCE; /* Where to read the temp from */

#define NO_SENSORS TEMP_SOURCES /* number of NO_SENSORS image */


#define CONFIG_CPU_ACPI  "cpu_acpi"
#define CONFIG_HDDTEMP   "hddtemp"
#define CONFIG_LM_SENSORS "lm_sensors"
#define CONFIG_COMMON	 "common"
#define CONFIG_DEV_NAMES "device_names"
#define CONFIG_SENSOR_DISPLAY "display"
#define CONFIG_SENSOR_ALIAS   "alias"
#define CONFIG_SENSOR_ICON    "icon"

const char * TEMP_SOURCE_NAMES[] = { CONFIG_CPU_ACPI, 
				     CONFIG_HDDTEMP,
                                     CONFIG_LM_SENSORS};

const float TEMP_DELIM_HIGH_DEFAULT[] = { 52.0, 48.0, 50.0 };
const float TEMP_DELIM_CRITICAL_DEFAULT[] = { 62.0, 58.0, 60.0 };

 
enum
{
    HORIZONTAL = 0,
    VERTICAL 
} APPLET_ORIENTATION; /* Applet direction*/

enum
{
    ENV_GNOME_PANEL = 0,
    ENV_ELSE
} APPLET_ENV;  /* where does the applet run */

const char * NOTEBOOK_NAMES[] = { "CPU", "Harddisk", "Lm-sensors" };

enum 
{
    I_HIGH_TEMP = 0,
    I_CRITICAL_TEMP,
    I_NORMAL_TEMP
};

enum
{
    TEMP_UNIT_CELSIUS = 0,
    TEMP_UNIT_FAHRENHEIT,
    TEMP_UNIT_KELVIN
};

const char * TEMPERATURE_NAMES[] = { "high temperature", 
				     "critical temperature", 
				     "normal temperature"};

typedef struct {
    int x;
    int y;
} rect_t;


typedef struct {
    GdkPixbuf *icon;
    int ico_x;
    int ico_y;

    GdkPixbuf *text;
    int txt_x;
    int txt_y;
} temp_image_t; /* contains all information needet to render a part of 
		   the applet */


struct _gt_setup_
{
    /* The colors */

    GaiColor col_okay;
    GaiColor col_high;
    GaiColor col_critical;
    GaiColor col_bg;

    int col_bg_use_gtk; /* use gtk background */

    int use_default_font;
    char *font_name;
    int font_size;
    int font_feature;

    /* sensor temperature lists */
    GSList *sl_display; /* temperatures to display */
    GSList *sl_source[TEMP_SOURCES]; 

    GSList *sl_display_pos;


    int   temp_unit; /* kelvin, celsius, fahrenheit */
		
    float temp_delim [TEMP_SOURCES][2];
    int   enable_temp_source [TEMP_SOURCES];

    GdkPixbuf *icon [TEMP_SOURCES];

    GdkPixbuf *bg; /* Pixbuf for the background */
    rect_t bg_dim; /* size of the bg */
    
		
    int temps_at_once;  /* number of temperatures that are displayed at once */
    temp_image_t *temp_img;

    int orientation; /* HORIZONTAL or VERTICAL */
    int env;  /* where does the applet run */

    /* border/spacing */
    int border;
    int spacing;
};

typedef struct _gt_setup_ gt_setup;



/************************************************************
 * Function forward decleration                             *
 ************************************************************/


gboolean update_temp (); /* callback function that does all
			    the nice things you see */

void create_pref (); /* load config and create pref. struct */

void load_config (); /* load the configuration from disk */

void gai_temp_settings(); /* save settings */

void draw_applet (GdkPixbuf *bg);  /* the drawing function */

void calc_applet_size (int *x, int *y);

/************************************************************/
/* and now some small helper functions                      */
/************************************************************/
void draw_background (GdkPixbuf *bg);

int get_sensor_type_from_stemp (sSensorTemp *stemp);

GdkPixbuf * get_icon_from_stemp (sSensorTemp *stemp);

GaiColor get_color_from_temp (sSensorTemp *stemp);

char *create_temp_str(sSensorTemp *stemp);


/* and a callback */

void select_font ();

#endif /* GAI_TEMP_H */
